==> nextcloud-29.0.5.tgz: nextcloud/apps/viewer/l10n/it.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visualizzatore",
    "Simple file viewer with slideshow for media" : "Semplice visualizzatore di file con presentazioni per i media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mostra le ultime foto e video delle tue vacanze come nei film, mostra uno scorcio del tuo ultimo romanzo direttamente da Nextcloud, scegli la migliore GIF della tua raccolta grazie all'anteprima diretta dei tuoi file preferiti e molto altro!",
    "Your browser does not support audio." : "Il tuo browser non supporta l'audio.",
    "Error loading {name}" : "Errore di caricamento di {name}",
    "Image saved" : "Immagine salvata",
    "Error saving image" : "Errore durante il salvataggio dell'immagine",
    "Unsaved changes" : "Modifiche non salvate",
    "Drop changes" : "Scarta le modifiche",
    "Play the live photo" : "Riproduci la foto live",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Il tuo browser non supporta i video.",
    "Edit" : "Modifica",
    "Exit full screen" : "Esci da schermo intero",
    "Full screen" : "Schermo intero",
    "Open sidebar" : "Apri la barra laterale",
    "Download" : "Scarica",
    "Delete" : "Elimina",
    "This file no longer exists" : "Questo file non esiste più",
    "There is no plugin available to display this file type" : "Non c'è alcuna estensione per visualizzare questo tipo di file",
    "View" : "Visualizza",
    "Name" : "Nome",
    "Save" : "Salva",
    "Save as" : "Salva come",
    "Back" : "Indietro",
    "Loading …" : "Caricamento …",
    "Reset" : "Ripristina",
    "All changes will be lost." : "Tutte le modifiche verranno perse.",
    "Are you sure you want to continue?" : "Sei sicuro di voler continuare?",
    "Cancel" : "Annulla",
    "Continue" : "Continua",
    "Undo" : "Annulla",
    "Redo" : "Rifai",
    "Show original image" : "Mostra immagine originale",
    "Zoom in" : "Ingrandisci",
    "Zoom out" : "Rimpicciolisci",
    "Toggle zoom menu" : "Cambia menu ingrandimento",
    "Adjust" : "Regola",
    "Fine-tune" : "Messa a punto",
    "Filters" : "Filtri",
    "Watermark" : "Filigrana",
    "Draw" : "Disegna",
    "Resize" : "Ridimensiona",
    "Invalid image." : "Immagine non valida.",
    "Error while uploading the image." : "Errore durante il caricamento dell'immagine.",
    "are not images" : "non sono immagini",
    "is not an image" : "non è un'immagine",
    "to be uploaded" : "da inviare",
    "Crop" : "Ritaglia",
    "Original" : "Originale",
    "Custom" : "Personalizzato",
    "Square" : "Quadrato",
    "Landscape" : "Orizzontale",
    "Portrait" : "Ritratto",
    "Ellipse" : "Ellisse",
    "Classic TV" : "TV classica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Freccia",
    "Blur" : "Sfocatura",
    "Brightness" : "Luminosità",
    "Contrast" : "Contrasto",
    "Un-flip X" : "De-capovolgi X",
    "Flip X" : "Capovolgi X",
    "Un-flip Y" : "De-capovolgi Y",
    "Flip Y" : "Capovolgi Y",
    "HSV" : "HSV",
    "Hue" : "Tonalità",
    "Saturation" : "Saturazione",
    "Value" : "Valore",
    "Image" : "Immagine",
    "Importing …" : "Importazione …",
    "+ Add image" : "+ Aggiungi immagine",
    "Line" : "Linea",
    "Pen" : "Penna",
    "Polygon" : "Poligono",
    "Sides" : "Lati",
    "Rectangle" : "Rettangolo",
    "Corner Radius" : "Raggio dell'angolo",
    "Width in pixels" : "Larghezza in pixel",
    "Height in pixels" : "Altezza in pixel",
    "Toggle ratio lock" : "Cambia blocco rapporto",
    "Reset to original image size" : "Ripristina a dimensione originale immagine",
    "Rotate" : "Ruota",
    "Text" : "Testo",
    "Text spacing" : "Spaziatura testo",
    "Text alignment" : "Allineamento testo",
    "Font family" : "Famiglia caratteri",
    "Size" : "Dimensione",
    "Letter spacing" : "Spaziatura lettere",
    "Line height" : "Altezza riga",
    "Warmth" : "Calore",
    "+ Add watermark" : "+ Aggiungi filigrana",
    "Choose watermark type" : "Scegli tipo di filigrana",
    "Upload watermark" : "Invia filigrana",
    "Add as text" : "Aggiungi come testo",
    "Padding" : "Riempimento",
    "Shadow" : "Ombra",
    "Horizontal" : "Orizzontale",
    "Vertical" : "Verticale",
    "Opacity" : "Opacità",
    "Position" : "Posizione",
    "Stroke" : "Tratto",
    "Save image as" : "Salva immagine come",
    "Extension" : "Estensione",
    "Name is required." : "Il nome è richiesto.",
    "Quality" : "Qualità",
    "Saved image size (width x height)" : "Salva dimensione immagine (largh. x altez.)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Nota che l'area di ritaglio selezionata è più piccola del ridimensionamento applicato, il che potrebbe causare perdita di qualità",
    "Actual size (100%)" : "Dimensione effettiva (100%)",
    "Fit size" : "Adatta dimensione"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/viewer/l10n/it.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visualizzatore",
    "Simple file viewer with slideshow for media" : "Semplice visualizzatore di file con presentazioni per i media",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Mostra le ultime foto e video delle tue vacanze come nei film, mostra uno scorcio del tuo ultimo romanzo direttamente da Nextcloud, scegli la migliore GIF della tua raccolta grazie all'anteprima diretta dei tuoi file preferiti e molto altro!",
    "Your browser does not support audio." : "Il tuo browser non supporta l'audio.",
    "Error loading {name}" : "Errore di caricamento di {name}",
    "Image saved" : "Immagine salvata",
    "Error saving image" : "Errore durante il salvataggio dell'immagine",
    "Unsaved changes" : "Modifiche non salvate",
    "Drop changes" : "Scarta le modifiche",
    "Play the live photo" : "Riproduci la foto live",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Il tuo browser non supporta i video.",
    "Edit" : "Modifica",
    "Exit full screen" : "Esci da schermo intero",
    "Full screen" : "Schermo intero",
    "Open sidebar" : "Apri la barra laterale",
    "Download" : "Scarica",
    "Delete" : "Elimina",
    "This file no longer exists" : "Questo file non esiste più",
    "There is no plugin available to display this file type" : "Non c'è alcuna estensione per visualizzare questo tipo di file",
    "View" : "Visualizza",
    "Name" : "Nome",
    "Save" : "Salva",
    "Save as" : "Salva come",
    "Back" : "Indietro",
    "Loading …" : "Caricamento …",
    "Reset" : "Ripristina",
    "All changes will be lost." : "Tutte le modifiche verranno perse.",
    "Are you sure you want to continue?" : "Sei sicuro di voler continuare?",
    "Cancel" : "Annulla",
    "Apply" : "Applica",
    "Warning" : "Attenzione",
    "Confirm" : "Conferma",
    "Discard changes" : "Scarta le modifiche",
    "Undo" : "Annulla",
    "Redo" : "Rifai",
    "Show original image" : "Mostra immagine originale",
    "Zoom in" : "Ingrandisci",
    "Zoom out" : "Rimpicciolisci",
    "Toggle zoom menu" : "Cambia menu ingrandimento",
    "Adjust" : "Regola",
    "Fine-tune" : "Messa a punto",
    "Filters" : "Filtri",
    "Watermark" : "Filigrana",
    "Draw" : "Disegna",
    "Resize" : "Ridimensiona",
    "Invalid image." : "Immagine non valida.",
    "Error while uploading the image." : "Errore durante il caricamento dell'immagine.",
    "are not images" : "non sono immagini",
    "is not an image" : "non è un'immagine",
    "to be uploaded" : "da inviare",
    "Crop" : "Ritaglia",
    "Original" : "Originale",
    "Custom" : "Personalizzato",
    "Square" : "Quadrato",
    "Landscape" : "Orizzontale",
    "Portrait" : "Ritratto",
    "Ellipse" : "Ellisse",
    "Classic TV" : "TV classica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Freccia",
    "Blur" : "Sfocatura",
    "Brightness" : "Luminosità",
    "Contrast" : "Contrasto",
    "Un-flip X" : "De-capovolgi X",
    "Flip X" : "Capovolgi X",
    "Un-flip Y" : "De-capovolgi Y",
    "Flip Y" : "Capovolgi Y",
    "HSV" : "HSV",
    "Hue" : "Tonalità",
    "Saturation" : "Saturazione",
    "Value" : "Valore",
    "Image" : "Immagine",
    "Importing …" : "Importazione …",
    "+ Add image" : "+ Aggiungi immagine",
    "Line" : "Linea",
    "Pen" : "Penna",
    "Polygon" : "Poligono",
    "Sides" : "Lati",
    "Rectangle" : "Rettangolo",
    "Corner Radius" : "Raggio dell'angolo",
    "Width in pixels" : "Larghezza in pixel",
    "Height in pixels" : "Altezza in pixel",
    "Toggle ratio lock" : "Cambia blocco rapporto",
    "Reset to original image size" : "Ripristina a dimensione originale immagine",
    "Rotate" : "Ruota",
    "Text" : "Testo",
    "Text spacing" : "Spaziatura testo",
    "Text alignment" : "Allineamento testo",
    "Font family" : "Famiglia caratteri",
    "Size" : "Dimensione",
    "Letter spacing" : "Spaziatura lettere",
    "Line height" : "Altezza riga",
    "Warmth" : "Calore",
    "+ Add watermark" : "+ Aggiungi filigrana",
    "Choose watermark type" : "Scegli tipo di filigrana",
    "Upload watermark" : "Invia filigrana",
    "Add as text" : "Aggiungi come testo",
    "Padding" : "Riempimento",
    "Shadow" : "Ombra",
    "Horizontal" : "Orizzontale",
    "Vertical" : "Verticale",
    "Opacity" : "Opacità",
    "Position" : "Posizione",
    "Stroke" : "Tratto",
    "Save image as" : "Salva immagine come",
    "Extension" : "Estensione",
    "Name is required." : "Il nome è richiesto.",
    "Quality" : "Qualità",
    "Saved image size (width x height)" : "Salva dimensione immagine (largh. x altez.)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Nota che l'area di ritaglio selezionata è più piccola del ridimensionamento applicato, il che potrebbe causare perdita di qualità",
    "Actual size (100%)" : "Dimensione effettiva (100%)",
    "Fit size" : "Adatta dimensione",
    "Menu" : "Menu",
    "Height" : "Altezza"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
